@@ -1,22 +1,25 @@
 ######################################################################
 # ad.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: ad.inc.pl,v 1.18 2011/09/01 12:24:21 papu Exp $
+# $Id: ad.inc.pl,v 1.269 2012/02/20 11:21:12 papu Exp $
 #
-# "ad plugin" version 1.05 $$
-# Author: Nanami http://nanakoch.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# "ad" version 1.07 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
-# Return LF:Code=EUC-JP 1TAB=4Spaces
+# Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
 
+$PLUGIN="ad";
+$VERSION="1.07";
+
 use strict;
 
 $AD::USECOOKIE=0		# only PyukiWiki ver 0.1.6 or later
@@ -64,7 +67,8 @@ sub plugin_ad_view {
 				&& ($::AD_DB_EXPIRE{"$space\_$id"} eq 0
 				||  $::AD_DB_EXPIRE{"$space\_$id"} >= time-86400)) {
 				for(my $i=0; $i<$::AD_DB_PRIORITY{"$space\_$id"}; $i++) {
-					$::AD_DB_VIEW{$space}.=$::AD_DB_HTML{"$space\_$id"} . "\f";
+					my $tmphtml=$::AD_DB_HTML{"$space\_$id"};
+					$::AD_DB_VIEW{$space}.=$tmphtml . "\f$id\0";
 					$::AD_DB_NUM{$space}++;
 				}
 			}
@@ -88,7 +92,21 @@ sub plugin_ad_view {
 		}
 	}
 	$::AD_DB_COUNT{$space}++;
-	return (split(/\f/,$::AD_DB_VIEW{$space}))[($::AD_SESSION + $::AD_DB_COUNT{$space}*11) % $::AD_DB_NUM{$space}];
+	my $retval=(split(/\0/,$::AD_DB_VIEW{$space}))[($::AD_SESSION + $::AD_DB_COUNT{$space}*11) % $::AD_DB_NUM{$space}];
+	my ($ret,$id)=split(/\f/,$retval);
+
+	# XHTMLʰ
+	$ret=~s/<[Ii][Mm][Gg] (.+?)>/<img $1 \/>/g;
+	$ret=~s/<[Ii][Mm][Gg] (.+?) \/ \/>/<img $1 \/>/g;
+
+	# URL񤭴
+	if(&plugin_ad_pyukiver >= 2) {
+		my $loop=1;
+		$ret=~s/[\x0a|\x0d]//g;
+		$ret=~s/<[Aa]\s/\f /g;
+		$ret=~s/\f(([^<]*))[Hh][Rr][Ee][Ff]="?(($::isurl))"?(([^<]*))>(([^\f]*))<\/[Aa]>/@{[&make_link_target("$::script?cmd=ad&amp;c=@{[$loop++]}&amp;p=@{[&dbmname($::form{mypage})]}&amp;l=$id", "adlink", "_blank", $8, 1)]}$8<\/a>/g;
+	}
+	return $ret;
 }
 
 sub plugin_ad_readdb {
@@ -135,13 +153,47 @@ sub plugin_ad_readdb {
 }
 
 sub plugin_ad_action {
-	require "$::plugin_dir/ad_edit.inc.pl";
-	return &plugin_ad_edit_start;
-}
+	my $id=$::form{l};
+	my $c=$::form{c};
+	my $p=$::form{p};
+	if($id eq '' && $c+0 eq 0) {
+		require "$::plugin_dir/ad_edit.inc.pl";
+		return &plugin_ad_edit_start;
+	}
+	if(&plugin_ad_pyukiver >= 2) {
+		&plugin_ad_readdb;
+		foreach my $key(keys %::AD_DB_HTML) {
+			if($key=~/$id$/) {
+				my $tmphtml=$::AD_DB_HTML{$key};
+				my @url=$tmphtml=~/<[Aa].+?[Hh][Rr][Ee][Ff]="($::isurl)"/g;
+				my $url=$url[$c-1];
+				print &http_header("Status: 302","Location: $url\n\n");
+				if(&plugin_ad_pyukiver >= 1) {
+					require "plugin/counter.inc.pl";
+					&plugin_counter_do("link\_$url","w");
+				}
+				if(&plugin_ad_pyukiver >= 2) {
+					if($::_exec_plugined{logs}>1) {
+						my $cmd="ck";
+						$::form{p}=&undbmname($::form{p});
+						my $page=&code_convert(\$::form{p}, $::defaultcode);
+						my $link=$url;
+						$page="$page<>$link";
 
-# ʲɾcookie롼󡢾ΥСǤɸಽޤ
-# 椤äȤcookie롼˻ƤΤϳΤǤ
-# http://www.cup.com/yui/
+						my $filename=&date("Y-m-d");
+						&getremotehost;
+						my $user=$::authadmin_cookie_user_name;
+						my $logtxt=<<EOM;
+$ENV{REMOTE_HOST} $ENV{REMOTE_ADDR}\t@{[&date($logs::date_format)]} @{[&date($logs::time_format)]}\t$user\t$ENV{REQUEST_METHOD}\t$cmd\t$::lang\t$page\t$ENV{HTTP_USER_AGENT}\t$ENV{HTTP_REFERER}
+EOM
+						&plugin_logs_add($filename, $logtxt);
+					}
+				}
+				exit;
+			}
+		}
+	}
+}
 
 sub plugin_ad_cookie_getcookie {
 	my($cookieID,%buf)=@_;
@@ -186,10 +238,11 @@ sub plugin_ad_cookie_setcookie{
 	$::HTTP_HEADER.="\n";
 }
 
-# 0.1.6̤ʹߤå
+# 0.2.0/0.1.6̤ʹߤå
 sub plugin_ad_pyukiver {
 	my ($v,$s)=split(/\-/,$::version);
 	$v=~s/\.//g;
+	return 2 if($v+0>=20);
 	return 1 if($v+0>=16);
 	return 0;
 }
@@ -312,13 +365,17 @@ Install resource file of 'ad_edit.en.txt' in   $::data_home. It is not necessary
 
 =item PyukiWiki/Plugin/Nanami/ad/
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Nanami/ad/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Nanami/ad/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/ad.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/ad.inc.pl?view=log>
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/ad_edit.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/ad.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/ad_edit.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/ad_edit.inc.pl?view=log>
 
 =back
 
@@ -332,17 +389,17 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2011 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
